@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintService.cpp 6986 2007-04-09 12:07:42Z chpe $
+ *  $Id: GeckoPrintService.cpp 7083 2007-06-14 12:19:32Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -238,7 +238,7 @@ GeckoPrintService::ShowPrintDialog (nsIDOMWindow *aParent,
   g_object_unref (settings);
   settings = settingsCopy;
 
-  rv = session->SetSettings (settings, pageSetup, printer);
+  rv = session->SetSettings (aSettings, settings, pageSetup, printer);
 
   /* Now translate the settings to nsIPrintSettings */
   if (NS_SUCCEEDED (rv)) {
