@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoPrintSession.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: GeckoPrintSession.h 7083 2007-06-14 12:19:32Z chpe $
  */
 
 #ifndef GECKO_PRINT_SESSION_H
@@ -58,7 +58,7 @@ class GeckoPrintSession : public nsIPrintSession,
     NS_DECL_NSIPRINTPROGRESS
     NS_DECL_NSIPRINTPROGRESSPARAMS
 
-    nsresult SetSettings (GtkPrintSettings*, GtkPageSetup*, GtkPrinter*);
+    nsresult SetSettings (nsIPrintSettings *, GtkPrintSettings*, GtkPageSetup*, GtkPrinter*);
     void GetSourceFile (nsACString&);
 
     static GeckoPrintSession *FromSettings (nsIPrintSettings *);
@@ -70,6 +70,7 @@ class GeckoPrintSession : public nsIPrintSession,
     void JobError (const char *);
 
   private:
+    nsCOMPtr<nsIPrintSettings> mPrintSettings;
     GtkPrintSettings *mSettings;
     GtkPageSetup *mPageSetup;
     GtkPrinter *mPrinter;
