@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-password-dialog.c 6940 2007-03-05 19:17:20Z chpe $
+ *  $Id: ephy-password-dialog.c 6978 2007-03-28 22:29:23Z chpe $
  */
 
 #ifndef DONT_HAVE_CONFIG_H
@@ -487,6 +487,7 @@ ephy_password_dialog_constructor (GType type,
 	/* Removed unused table rows */
 	gtk_table_resize (table, row, 2);
 
+#if 0
 	if (priv->flags & EPHY_PASSWORD_DIALOG_FLAGS_SHOW_REMEMBER)
 	{
 		GSList *group = NULL;
@@ -508,6 +509,7 @@ ephy_password_dialog_constructor (GType type,
 
 		gtk_widget_set_no_show_all (rbox, !gnome_keyring_is_available ());
 	}
+#endif
 
 	gtk_dialog_add_button (dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (dialog, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT);
