@@ -15,9 +15,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.25 2006/12/04 22:10:40 chpe Exp $
+ *  $Id: ephy-statusbar.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -32,9 +32,9 @@
 #include <gtk/gtkprogressbar.h>
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtkimage.h>
-#include <gtk/gtkframe.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkvseparator.h>
+#include <gtk/gtkversion.h>
 
 static void ephy_statusbar_class_init	(EphyStatusbarClass *klass);
 static void ephy_statusbar_init		(EphyStatusbar *t);
@@ -92,7 +92,7 @@ ephy_statusbar_get_type (void)
 	return type;
 }
 
-/* FIXME: remove this hack once gtk bug #372452 is fixed! */
+#if !GTK_CHECK_VERSION (2, 11, 0)
 static void
 ephy_statusbar_size_allocate (GtkWidget *widget,
 			      GtkAllocation *allocation)
@@ -110,18 +110,23 @@ ephy_statusbar_size_allocate (GtkWidget *widget,
 
 	gstatusbar->label = label;
 }
+#endif /* GTK 2.11.0 */
 
 static void
 ephy_statusbar_class_init (EphyStatusbarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+#if !GTK_CHECK_VERSION (2, 11, 0)
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+#endif
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_statusbar_finalize;
 
+#if !GTK_CHECK_VERSION (2, 11, 0)
 	widget_class->size_allocate = ephy_statusbar_size_allocate;
+#endif
 
 	signals[LOCK_CLICKED] =
 		g_signal_new
